@@ -1,7 +1,9 @@
 use std::io;
-use std::net::{self, Ipv4Addr, SocketAddr, SocketAddrV4, ToSocketAddrs};
+use std::net::{self, SocketAddr, ToSocketAddrs};
 use std::os::unix::io::{AsRawFd, FromRawFd};
 
+use os_socketaddr::OsSocketAddr;
+
 use super::stream::TcpStream;
 use crate::driver::Action;
 
@@ -23,10 +25,14 @@ impl TcpListener {
         let completion = Action::accept(self.inner.as_raw_fd())?.await;
         let fd = completion.result?;
         let stream = unsafe { TcpStream::from_raw_fd(fd) };
-        let addr = stream
-            .peer_addr()
-            .unwrap_or_else(|_| SocketAddr::V4(SocketAddrV4::new(Ipv4Addr::new(0, 0, 0, 0), 0)));
-        Ok((stream, addr))
+        let os_socket_addr = unsafe {
+            OsSocketAddr::from_raw_parts(
+                &completion.action.socketaddr.0 as *const _ as _,
+                completion.action.socketaddr.1 as usize,
+            )
+        };
+        let socket_addr = os_socket_addr.into_addr().unwrap();
+        Ok((stream, socket_addr))
     }
 
     pub fn local_addr(&self) -> io::Result<SocketAddr> {
